@@ -175,7 +175,7 @@ readFam = function(famfile, useDVI = NA, Xchrom = FALSE, prefixAdded = "added_",
   # Add extras to id & sex
   nFem = as.integer(x[kr.line + 1])
   nMal = as.integer(x[kr.line + 2])
-  id = c(id, character(length = nFem + nMal))
+  id = c(id, sprintf("extra_%d", seq_len(nFem + nMal)))
   sex = c(sex, rep.int(2:1, c(nFem, nMal)))
 
   # Initialise fidx, midx
@@ -219,7 +219,7 @@ readFam = function(famfile, useDVI = NA, Xchrom = FALSE, prefixAdded = "added_",
       # Add extras in the i'th pedigree
       nFem.i = as.integer(x[ped.line + 2])
       nMal.i = as.integer(x[ped.line + 3])
-      id.i = c(id, character(nFem.i + nMal.i))
+      id.i = c(id, sprintf("extra_ped%d_%d", ped.idx, seq_len(nFem.i + nMal.i)))
       sex.i = c(sex, rep.int(2:1, c(nFem.i, nMal.i)))
       fidx.i = c(fidx, integer(nFem.i + nMal.i))
       midx.i = c(midx, integer(nFem.i + nMal.i))
@@ -231,18 +231,18 @@ readFam = function(famfile, useDVI = NA, Xchrom = FALSE, prefixAdded = "added_",
       # Add fixed relations
       nRel.i = as.integer(x[ped.line + 4])
       rel.line = ped.line + 5
-      for(i in seq_len(nRel.i)) {
+      for(j in seq_len(nRel.i)) {
         par.idx = as.integer(x[rel.line]) + 1
         child.idx = as.integer(x[rel.line+1]) + 1
         if(is.na(par.idx)) {
           if(grepl("Direct", x[rel.line])) {
             par.idx = as.integer(substring(x[rel.line], 1, 1)) + 1
             twins = c(twins, list(par.idx, child.idx))
-            if(verbose) cat("  Twins:", toString(id[c(par.idx, child.idx)]), "\n")
+            if(verbose) cat("  Twins:", toString(id.i[c(par.idx, child.idx)]), "\n")
             stop2("File contains twins - this is not supported yet")
           }
         }
-        if(sex[par.idx] == 1)
+        if(sex.i[par.idx] == 1)
           fidx.i[child.idx] = par.idx
         else
           midx.i[child.idx] = par.idx
@@ -400,10 +400,23 @@ readFam = function(famfile, useDVI = NA, Xchrom = FALSE, prefixAdded = "added_",
     femaleMutMat = mutationMatrix(model = femaleMod, alleles = als, afreq = frqs,
                                   rate = mutrate.fem, rate2 = mutrate2.fem, range = range.fem)
 
-    if(names(maleMod) == "step-stationary")
-      maleMutMat = pedmut::stabilize(maleMutMat, method = "PM")
-    if(names(femaleMod) == "step-stationary")
-      femaleMutMat = pedmut::stabilize(femaleMutMat, method = "PM")
+    if(names(maleMod) == "step-stationary") {
+      maleMutMat = tryCatch(pedmut::stabilize(maleMutMat, method = "PM"),
+        error = function(e) {
+          warning(sprintf("Database error, locus %s: Cannot stabilize mutation matrix. Changed to '%s' model.",
+                          loc.name, fallbackModel), call. = FALSE)
+          mutationMatrix(model = fallbackModel, alleles = als, afreq = frqs, rate = mutrate.mal)
+        })
+      if(pedmut::getParams(maleMutMat, "model") == fallbackModel)
+         maleMod = models[models == fallbackModel]
+    }
+
+    if(names(femaleMod) == "step-stationary") {
+      femaleMutMat = tryCatch(pedmut::stabilize(femaleMutMat, method = "PM"),
+        error = function(e) mutationMatrix(model = fallbackModel, alleles = als, afreq = frqs, rate = mutrate.fem))
+      if(pedmut::getParams(femaleMutMat, "model") == fallbackModel)
+         femaleMod = models[models == fallbackModel]
+    }
 
     # Print locus summary
     if(verbose) {
